import { defineProperty as _defineProperty } from '../_virtual/_rollupPluginBabelHelpers.mjs';
import { MetaplexError } from './MetaplexError.mjs';

/** @group Errors */
class IrysError extends MetaplexError {
  constructor(message, cause) {
    super(message, 'plugin', 'Irys', cause);
    _defineProperty(this, "name", 'IrysError');
  }
}

/** @group Errors */
class FailedToInitializeIrysError extends IrysError {
  constructor(cause) {
    const message = 'Irys could not be initialized. ' + 'Please check the underlying error below for more details.';
    super(message, cause);
    _defineProperty(this, "name", 'FailedToInitializeIrysError');
  }
}

/** @group Errors */
class FailedToConnectToIrysAddressError extends IrysError {
  constructor(address, cause) {
    const message = `Irys could not connect to the provided address [${address}]. ` + 'Please ensure the provided address is valid. Some valid addresses include: ' + '"https://node1.irys.xyz" for mainnet and "https://devnet.irys.xyz" for devnet';
    super(message, cause);
    _defineProperty(this, "name", 'FailedToConnectToIrysAddressError');
  }
}

/** @group Errors */
class AssetUploadFailedError extends IrysError {
  constructor(status) {
    const message = `The asset could not be uploaded to the Irys network and ` + `returned the following status code [${status}].`;
    super(message);
    _defineProperty(this, "name", 'AssetUploadFailedError');
  }
}

/** @group Errors */
class IrysWithdrawError extends IrysError {
  constructor(error) {
    const message = `The balance could not be withdrawn from the Irys network and ` + `returned the following error: ${error}.`;
    super(message);
    _defineProperty(this, "name", 'IrysWithdrawError');
  }
}

export { AssetUploadFailedError, FailedToConnectToIrysAddressError, FailedToInitializeIrysError, IrysError, IrysWithdrawError };
//# sourceMappingURL=IrysError.mjs.map
